==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/autoreplyplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/autoreplyplugin/autoreply.png
  0x0,0x0,0x2,0x82,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x2,0x24,0x49,0x44,0x41,0x54,0x78,0xda,0x9c,
  0x52,0x4d,0x68,0x13,0x41,0x14,0xfe,0x66,0x7f,0x3a,0xbb,0x9,0xa1,0xe2,0xd1,0x43,
  0x8e,0x1e,0x62,0x13,0xbd,0x1a,0x89,0xc6,0xa,0x2a,0xad,0x8d,0x3f,0xe7,0x4a,0xb0,
  0x78,0x56,0x3c,0x79,0xad,0x8,0x22,0xd4,0xab,0x8,0xa5,0x48,0x20,0x17,0xaf,0x56,
  0x84,0x14,0xf1,0xa2,0xe2,0xa5,0x82,0x5b,0xb3,0x11,0xf4,0xe0,0xa1,0x4a,0xc1,0xbf,
  0x53,0xc5,0x9f,0xcd,0xee,0x8c,0xef,0xcd,0x6e,0x92,0xaa,0x3d,0xa8,0xb3,0xcc,0xee,
  0xec,0xcc,0xfb,0xbe,0xf9,0xbe,0xf7,0x9e,0x68,0xb7,0xdb,0xd7,0x93,0x24,0xb9,0xac,
  0xb5,0x86,0x10,0x2,0x8e,0x63,0x5f,0x99,0x9d,0x3d,0x3b,0x8f,0xbf,0x18,0x6,0xd3,
  0x6a,0xb5,0x74,0xa3,0x71,0x92,0xc0,0xbc,0x1,0x2c,0x2f,0xdf,0x45,0x14,0x45,0x10,
  0x69,0xc8,0x36,0x30,0x61,0x2e,0xb2,0x2c,0xeb,0xe9,0xb9,0xb9,0xb9,0x3,0xe,0xb3,
  0x70,0xf4,0xbd,0xfb,0x2b,0x98,0x9e,0x3a,0x8a,0x24,0x89,0x31,0x79,0xf8,0x8,0x2c,
  0xc4,0xb4,0xad,0xd,0x91,0xc8,0xa8,0x78,0x2a,0x2d,0x10,0x2b,0xe0,0xf1,0x93,0x47,
  0x55,0xa6,0x73,0xf8,0xa5,0x94,0x42,0x2e,0x97,0x23,0x5,0xca,0x44,0xbd,0x7e,0xf5,
  0x12,0xbd,0x7c,0xd,0xe1,0xc6,0x17,0x58,0x62,0x74,0xb7,0xa2,0xb3,0xd2,0xae,0x3c,
  0x8e,0x8f,0xbf,0x49,0xe5,0xe,0x8,0x18,0xe4,0x79,0x12,0x8c,0xe7,0x1f,0x29,0x25,
  0x3e,0xf6,0x1d,0x8c,0xef,0xc8,0xff,0xa1,0xe0,0x53,0xe4,0xe0,0x7,0x59,0xcc,0xf0,
  0x29,0x1,0xdb,0xf0,0xa4,0x97,0xdd,0xa2,0x51,0xda,0x33,0x81,0x92,0xfa,0x4c,0x36,
  0x34,0x6,0x2,0xf4,0x16,0x15,0xca,0x2a,0x22,0x58,0x7b,0xb1,0x45,0x1,0x14,0xa4,
  0x2f,0x53,0xb,0x34,0xd6,0xdf,0x6d,0x18,0x88,0xc8,0xe0,0x83,0x4,0x6b,0x7a,0x54,
  0x92,0xa0,0x58,0x2c,0xe,0x9,0x53,0x5,0x84,0xf3,0x49,0xb6,0xa1,0x27,0x90,0xef,
  0xe7,0xb0,0xfa,0x6c,0x15,0xbd,0x5e,0xf,0x95,0x4a,0x5,0xdd,0x6e,0x17,0x13,0xe5,
  0x32,0xd6,0x82,0x0,0xcd,0x66,0x93,0x2b,0x30,0xcc,0xcb,0xd0,0x82,0x24,0xb,0x2c,
  0x3f,0xb5,0x23,0x71,0xa8,0x56,0xc3,0x64,0xbd,0x6e,0x82,0xea,0xb4,0xe6,0xfd,0x83,
  0xd5,0x2a,0xa2,0x7e,0x9f,0x8,0x6c,0xf3,0x3f,0x22,0xa0,0x69,0x2c,0x64,0x6e,0x79,
  0xbd,0xf2,0xe0,0xa1,0x51,0xb0,0xb7,0x52,0x26,0x5,0xa1,0x51,0x10,0x4,0xcf,0x71,
  0xe9,0xe2,0x5,0x8,0x7b,0x1b,0x5,0x6c,0x81,0xbf,0xec,0xc2,0x95,0x3e,0xa6,0x1a,
  0xa7,0x70,0xe2,0xf4,0x19,0x38,0xe4,0x6f,0x86,0x1a,0x2d,0xa6,0x94,0x1e,0x9b,0x9e,
  0x81,0x8a,0xbe,0xc1,0xb1,0xed,0x5f,0xcb,0x68,0x51,0xb1,0xfd,0x31,0x1f,0x71,0x3f,
  0x32,0x39,0x90,0x5e,0xe,0x3b,0x17,0x76,0x3,0xef,0x5d,0xdc,0xda,0x7f,0x15,0x61,
  0x18,0xe2,0x66,0xe1,0xe,0xf0,0x56,0xe1,0xc3,0x8d,0x2e,0x5c,0xd7,0x1d,0x25,0x91,
  0xdb,0xd2,0xd4,0x81,0x3a,0xd0,0x6c,0x90,0xbc,0x42,0xde,0xc3,0xd7,0xf9,0x75,0x93,
  0xfd,0xf3,0x3a,0xad,0xc2,0x77,0x5c,0xa3,0x86,0x3,0xa,0x54,0x5,0x39,0x66,0xf,
  0x13,0xc9,0xad,0xbc,0xd9,0xe9,0x74,0xa,0xdc,0x8d,0x59,0x8f,0xe3,0xf6,0xd2,0xe2,
  0xb0,0x51,0x7e,0xef,0x3,0x5e,0x59,0x69,0xdc,0xe6,0xe0,0x7c,0x1f,0x4d,0x1b,0xff,
  0x3e,0x12,0xba,0x3c,0x10,0x83,0x72,0xfc,0xef,0xf8,0x29,0xc0,0x0,0xdf,0x61,0xee,
  0x33,0x7d,0x8a,0x3d,0xd4,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // autoreply.png
  0x0,0xd,
  0x6,0xae,0x87,0x67,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x79,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/autoreply.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/autoreplyplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/autoreplyplugin/autoreply.png
  0x0,0x0,0x2,0x82,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x2,0x24,0x49,0x44,0x41,0x54,0x78,0xda,0x9c,
  0x52,0x4d,0x68,0x13,0x41,0x14,0xfe,0x66,0x7f,0x3a,0xbb,0x9,0xa1,0xe2,0xd1,0x43,
  0x8e,0x1e,0x62,0x13,0xbd,0x1a,0x89,0xc6,0xa,0x2a,0xad,0x8d,0x3f,0xe7,0x4a,0xb0,
  0x78,0x56,0x3c,0x79,0xad,0x8,0x22,0xd4,0xab,0x8,0xa5,0x48,0x20,0x17,0xaf,0x56,
  0x84,0x14,0xf1,0xa2,0xe2,0xa5,0x82,0x5b,0xb3,0x11,0xf4,0xe0,0xa1,0x4a,0xc1,0xbf,
  0x53,0xc5,0x9f,0xcd,0xee,0x8c,0xef,0xcd,0x6e,0x92,0xaa,0x3d,0xa8,0xb3,0xcc,0xee,
  0xec,0xcc,0xfb,0xbe,0xf9,0xbe,0xf7,0x9e,0x68,0xb7,0xdb,0xd7,0x93,0x24,0xb9,0xac,
  0xb5,0x86,0x10,0x2,0x8e,0x63,0x5f,0x99,0x9d,0x3d,0x3b,0x8f,0xbf,0x18,0x6,0xd3,
  0x6a,0xb5,0x74,0xa3,0x71,0x92,0xc0,0xbc,0x1,0x2c,0x2f,0xdf,0x45,0x14,0x45,0x10,
  0x69,0xc8,0x36,0x30,0x61,0x2e,0xb2,0x2c,0xeb,0xe9,0xb9,0xb9,0xb9,0x3,0xe,0xb3,
  0x70,0xf4,0xbd,0xfb,0x2b,0x98,0x9e,0x3a,0x8a,0x24,0x89,0x31,0x79,0xf8,0x8,0x2c,
  0xc4,0xb4,0xad,0xd,0x91,0xc8,0xa8,0x78,0x2a,0x2d,0x10,0x2b,0xe0,0xf1,0x93,0x47,
  0x55,0xa6,0x73,0xf8,0xa5,0x94,0x42,0x2e,0x97,0x23,0x5,0xca,0x44,0xbd,0x7e,0xf5,
  0x12,0xbd,0x7c,0xd,0xe1,0xc6,0x17,0x58,0x62,0x74,0xb7,0xa2,0xb3,0xd2,0xae,0x3c,
  0x8e,0x8f,0xbf,0x49,0xe5,0xe,0x8,0x18,0xe4,0x79,0x12,0x8c,0xe7,0x1f,0x29,0x25,
  0x3e,0xf6,0x1d,0x8c,0xef,0xc8,0xff,0xa1,0xe0,0x53,0xe4,0xe0,0x7,0x59,0xcc,0xf0,
  0x29,0x1,0xdb,0xf0,0xa4,0x97,0xdd,0xa2,0x51,0xda,0x33,0x81,0x92,0xfa,0x4c,0x36,
  0x34,0x6,0x2,0xf4,0x16,0x15,0xca,0x2a,0x22,0x58,0x7b,0xb1,0x45,0x1,0x14,0xa4,
  0x2f,0x53,0xb,0x34,0xd6,0xdf,0x6d,0x18,0x88,0xc8,0xe0,0x83,0x4,0x6b,0x7a,0x54,
  0x92,0xa0,0x58,0x2c,0xe,0x9,0x53,0x5,0x84,0xf3,0x49,0xb6,0xa1,0x27,0x90,0xef,
  0xe7,0xb0,0xfa,0x6c,0x15,0xbd,0x5e,0xf,0x95,0x4a,0x5,0xdd,0x6e,0x17,0x13,0xe5,
  0x32,0xd6,0x82,0x0,0xcd,0x66,0x93,0x2b,0x30,0xcc,0xcb,0xd0,0x82,0x24,0xb,0x2c,
  0x3f,0xb5,0x23,0x71,0xa8,0x56,0xc3,0x64,0xbd,0x6e,0x82,0xea,0xb4,0xe6,0xfd,0x83,
  0xd5,0x2a,0xa2,0x7e,0x9f,0x8,0x6c,0xf3,0x3f,0x22,0xa0,0x69,0x2c,0x64,0x6e,0x79,
  0xbd,0xf2,0xe0,0xa1,0x51,0xb0,0xb7,0x52,0x26,0x5,0xa1,0x51,0x10,0x4,0xcf,0x71,
  0xe9,0xe2,0x5,0x8,0x7b,0x1b,0x5,0x6c,0x81,0xbf,0xec,0xc2,0x95,0x3e,0xa6,0x1a,
  0xa7,0x70,0xe2,0xf4,0x19,0x38,0xe4,0x6f,0x86,0x1a,0x2d,0xa6,0x94,0x1e,0x9b,0x9e,
  0x81,0x8a,0xbe,0xc1,0xb1,0xed,0x5f,0xcb,0x68,0x51,0xb1,0xfd,0x31,0x1f,0x71,0x3f,
  0x32,0x39,0x90,0x5e,0xe,0x3b,0x17,0x76,0x3,0xef,0x5d,0xdc,0xda,0x7f,0x15,0x61,
  0x18,0xe2,0x66,0xe1,0xe,0xf0,0x56,0xe1,0xc3,0x8d,0x2e,0x5c,0xd7,0x1d,0x25,0x91,
  0xdb,0xd2,0xd4,0x81,0x3a,0xd0,0x6c,0x90,0xbc,0x42,0xde,0xc3,0xd7,0xf9,0x75,0x93,
  0xfd,0xf3,0x3a,0xad,0xc2,0x77,0x5c,0xa3,0x86,0x3,0xa,0x54,0x5,0x39,0x66,0xf,
  0x13,0xc9,0xad,0xbc,0xd9,0xe9,0x74,0xa,0xdc,0x8d,0x59,0x8f,0xe3,0xf6,0xd2,0xe2,
  0xb0,0x51,0x7e,0xef,0x3,0x5e,0x59,0x69,0xdc,0xe6,0xe0,0x7c,0x1f,0x4d,0x1b,0xff,
  0x3e,0x12,0xba,0x3c,0x10,0x83,0x72,0xfc,0xef,0xf8,0x29,0xc0,0x0,0xdf,0x61,0xee,
  0x33,0x7d,0x8a,0x3d,0xd4,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // autoreply.png
  0x0,0xd,
  0x6,0xae,0x87,0x67,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x79,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/autoreply.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
